@@ -34,8 +34,9 @@ class BugReportDialog(QDialog, Ui_BugReportDialog):
         self.report_text.clear()
         self.traceback_text.clear()
 
-    def add_tb(self, type, value, tb):
-        thread_id = thread.get_ident()
+    def add_tb(self, thread_id, type, value, tb):
+        if not self.isVisible():
+            self.show()
         if thread_id == self.main_thread_id and self.main_traceback is None:
             self.main_traceback = (type, value, tb)
             self.update_tb_text()
@@ -60,7 +61,7 @@ class BugReportDialog(QDialog, Ui_BugReportDialog):
     def send_email(self):
         url = u"mailto:%s?subject=%s&body=%s\n\n%s" % (
             settings.BUG_REPORT_EMAIL, 
-            unicode(self.trUtf8("[Palette]: Bug report")),
+            settings.BUG_REPORT_EMAIL_SUBJECT,
             unicode(self.report_text.toPlainText()),
             unicode(self.traceback_text.toPlainText()))
         QDesktopServices.openUrl(QUrl(url))
